@@ -1,5 +1,7 @@
 """Animations related to movement."""
 
+from __future__ import annotations
+
 __all__ = [
     "Homotopy",
     "SmoothedVectorizedHomotopy",
@@ -8,7 +10,7 @@ __all__ = [
     "MoveAlongPath",
 ]
 
-from typing import TYPE_CHECKING, Any, Callable, Dict, Optional, Tuple
+from typing import TYPE_CHECKING, Any, Callable
 
 import numpy as np
 
@@ -16,17 +18,17 @@ from ..animation.animation import Animation
 from ..utils.rate_functions import linear
 
 if TYPE_CHECKING:
-    from ..mobject.mobject import Mobject
+    from ..mobject.mobject import Mobject, VMobject
 
 
 class Homotopy(Animation):
     def __init__(
         self,
-        homotopy: Callable[[float, float, float, float], Tuple[float, float, float]],
-        mobject: "Mobject",
+        homotopy: Callable[[float, float, float, float], tuple[float, float, float]],
+        mobject: Mobject,
         run_time: float = 3,
-        apply_function_kwargs: Optional[Dict[str, Any]] = None,
-        **kwargs
+        apply_function_kwargs: dict[str, Any] | None = None,
+        **kwargs,
     ) -> None:
         """
         Homotopy is a function from
@@ -38,13 +40,13 @@ class Homotopy(Animation):
         )
         super().__init__(mobject, run_time=run_time, **kwargs)
 
-    def function_at_time_t(self, t: float) -> Tuple[float, float, float]:
+    def function_at_time_t(self, t: float) -> tuple[float, float, float]:
         return lambda p: self.homotopy(*p, t)
 
     def interpolate_submobject(
         self,
-        submobject: "Mobject",
-        starting_submobject: "Mobject",
+        submobject: Mobject,
+        starting_submobject: Mobject,
         alpha: float,
     ) -> None:
         submobject.points = starting_submobject.points
@@ -56,8 +58,8 @@ class Homotopy(Animation):
 class SmoothedVectorizedHomotopy(Homotopy):
     def interpolate_submobject(
         self,
-        submobject: "Mobject",
-        starting_submobject: "Mobject",
+        submobject: Mobject,
+        starting_submobject: Mobject,
         alpha: float,
     ) -> None:
         super().interpolate_submobject(submobject, starting_submobject, alpha)
@@ -66,7 +68,7 @@ class SmoothedVectorizedHomotopy(Homotopy):
 
 class ComplexHomotopy(Homotopy):
     def __init__(
-        self, complex_homotopy: Callable[[complex], float], mobject: "Mobject", **kwargs
+        self, complex_homotopy: Callable[[complex], float], mobject: Mobject, **kwargs
     ) -> None:
         """
         Complex Homotopy a function Cx[0, 1] to C
@@ -77,7 +79,7 @@ class ComplexHomotopy(Homotopy):
             y: float,
             z: float,
             t: float,
-        ) -> Tuple[float, float, float]:
+        ) -> tuple[float, float, float]:
             c = complex_homotopy(complex(x, y), t)
             return (c.real, c.imag, z)
 
@@ -88,11 +90,11 @@ class PhaseFlow(Animation):
     def __init__(
         self,
         function: Callable[[np.ndarray], np.ndarray],
-        mobject: "Mobject",
+        mobject: Mobject,
         virtual_time: float = 1,
         suspend_mobject_updating: bool = False,
         rate_func: Callable[[float], float] = linear,
-        **kwargs
+        **kwargs,
     ) -> None:
         self.virtual_time = virtual_time
         self.function = function
@@ -100,7 +102,7 @@ class PhaseFlow(Animation):
             mobject,
             suspend_mobject_updating=suspend_mobject_updating,
             rate_func=rate_func,
-            **kwargs
+            **kwargs,
         )
 
     def interpolate_mobject(self, alpha: float) -> None:
@@ -130,10 +132,10 @@ class MoveAlongPath(Animation):
 
     def __init__(
         self,
-        mobject: "Mobject",
-        path: "VMobject",
-        suspend_mobject_updating: Optional[bool] = False,
-        **kwargs
+        mobject: Mobject,
+        path: VMobject,
+        suspend_mobject_updating: bool | None = False,
+        **kwargs,
     ) -> None:
         self.path = path
         super().__init__(
