@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import os
 import re
 import textwrap
@@ -297,7 +299,7 @@ class Mesh(Object3D):
             "u_model_matrix",
             opengl.matrix_to_shader_input(self.model_matrix),
         )
-        self.shader.set_uniform("u_view_matrix", renderer.camera.get_view_matrix())
+        self.shader.set_uniform("u_view_matrix", renderer.camera.formatted_view_matrix)
         self.shader.set_uniform(
             "u_projection_matrix",
             renderer.camera.projection_matrix,
