@@ -1,13 +1,18 @@
 """A scene suitable for vector spaces."""
 
+from __future__ import annotations
+
 __all__ = ["VectorScene", "LinearTransformationScene"]
 
-
-from typing import Optional
-
 import numpy as np
 from colour import Color
 
+from manim.mobject.geometry.arc import Dot
+from manim.mobject.geometry.line import Arrow, Line, Vector
+from manim.mobject.geometry.polygram import Rectangle
+from manim.mobject.graphing.coordinate_systems import Axes, NumberPlane
+from manim.mobject.opengl.opengl_mobject import OpenGLMobject
+from manim.mobject.text.tex_mobject import MathTex, Tex
 from manim.utils.config_ops import update_dict_recursively
 
 from .. import config
@@ -17,15 +22,11 @@ from ..animation.fading import FadeOut
 from ..animation.growing import GrowArrow
 from ..animation.transform import ApplyFunction, ApplyPointwiseFunction, Transform
 from ..constants import *
-from ..mobject.coordinate_systems import Axes, NumberPlane
-from ..mobject.geometry import Arrow, Dot, Line, Rectangle, Vector
 from ..mobject.matrix import Matrix
 from ..mobject.mobject import Mobject
-from ..mobject.opengl_mobject import OpenGLMobject
-from ..mobject.svg.tex_mobject import MathTex, Tex
 from ..mobject.types.vectorized_mobject import VGroup, VMobject
 from ..scene.scene import Scene
-from ..utils.color import BLUE_D, GREEN_C, GREY, LIGHT_GREY, RED_C, WHITE, YELLOW
+from ..utils.color import BLUE_D, GREEN_C, GREY, RED_C, WHITE, YELLOW
 from ..utils.rate_functions import rush_from, rush_into
 from ..utils.space_ops import angle_of_vector
 
@@ -78,7 +79,7 @@ class VectorScene(Scene):
         color : bool, optional
             The color of the axes. Defaults to WHITE.
         """
-        axes = Axes(color=color, tick_frequency=1)
+        axes = Axes(color=color, axis_config={"unit_size": 1})
         if animate:
             self.play(Create(axes))
         self.add(axes)
@@ -561,15 +562,15 @@ class LinearTransformationScene(VectorScene):
         self,
         include_background_plane: bool = True,
         include_foreground_plane: bool = True,
-        background_plane_kwargs: Optional[dict] = None,
-        foreground_plane_kwargs: Optional[dict] = None,
+        background_plane_kwargs: dict | None = None,
+        foreground_plane_kwargs: dict | None = None,
         show_coordinates: bool = False,
         show_basis_vectors: bool = True,
         basis_vector_stroke_width: float = 6,
         i_hat_color: Color = X_COLOR,
         j_hat_color: Color = Y_COLOR,
         leave_ghost_vectors: bool = False,
-        **kwargs
+        **kwargs,
     ):
 
         super().__init__(**kwargs)
